@@ -12,7 +12,7 @@
 
 linarr <- function(Y, Y_den, id = NULL, age, pl085, month_at_work,
                    weight = NULL,  sort = NULL, Dom = NULL,
-                   period = NULL, dataset = NULL, order_quant = 50L,
+                   period = NULL, dataset = NULL, order_quant = 50,
                    var_name = "lin_arr", checking = TRUE) {
 
    ## initializations
@@ -21,7 +21,7 @@ linarr <- function(Y, Y_den, id = NULL, age, pl085, month_at_work,
 
    if (checking) {
         order_quant <- check_var(vars = order_quant, varn = "order_quant",
-                                 varntype = "integer0100") 
+                                 varntype = "numeric0100") 
 
         Y <- check_var(vars = Y, varn = "Y", dataset = dataset,
                        ncols = 1, isnumeric = TRUE,
